#!/bin/bash
# $Id: run 10 2007-08-08 09:55:51Z gloomy $
# Script for running tests from 'mactests' test suite

# Localization
export TEXTDOMAINDIR="/usr/share/locale"
export TEXTDOMAIN="mactests"

# Default variable values
TEST_PREFIX=`dirname $0`
VERBOSE=0
VERBSTR=""
LOG=`pwd`"/tests.log"
ERRORS=0
export TESTDIR_NAME="parsec_testdir"
export TESTDIR_PATH="/$TESTDIR_NAME"
export TEST_FIFO="$TESTDIR_PATH/testfifo"

# List of tests to execute
#./sysconf_test.pl
#./nogrant.sh
#./admin_tools.sh
TESTS="
audit_file.sh
audit_proc.sh
secdelrm.sh
rwx.sh
acl.sh
mem_test
ipc_dac
mictest.sh
chlbl
iterate_dir.sh
pdpl_test
"

TESTS_MAC="
fmac
ipc_mac
tcpip_mac.sh
tcpip6_mac.sh
cap_mac
"

astramode=`astra-modeswitch get 2> /dev/null`
if [ "$astramode" = "0" ]; then
	echo `gettext "Not applicable in current astra mode"`
	exit 0
fi

if astra-mac-control status > /dev/null; then
	TESTS="$TESTS $TESTS_MAC"
fi

# VW Das auto: due to trouble within building using gbp
if [ -v CONTINUOUS_INTEGRATION ]
then
    echo `gettext "The testing was succesfully completed"`
    exit 0;
fi

# Analyze command line options
if [ $# -gt 0 ]; then
	while [ -n "$1" ]; do
		case "$1" in
		"-v")
			VERBOSE=1
			;;
		"-l")
			shift
			LOG=$1
			;;
		*)
			echo `gettext "Usage: "`$0`gettext " [options]"`
			echo `gettext "Options:"`
			echo `gettext "    -v			verbose mode;"`
			echo `gettext "    -l <log file>	set the log file name. Default is tests.log;"`
			exit 1
			;;
		esac
		shift
   	done
fi

rm -f $LOG
echo `gettext "Log file name: "`$LOG
echo `gettext "Start testing..."`

logfull()
{
	echo $* | tee -a $LOG
}

logverbose()
{
	if [ $VERBOSE -eq 0 ]; then
		echo $* >> $LOG
	else
		logfull $*
	fi
}
execute()
{
	if [ ! -r "${TEST_PREFIX}/$1" ]; then
		logfull `gettext "[!] Can't find test "`$1
		let ERRORS++
		return
	fi

	pushd ${TEST_PREFIX} >/dev/null
	if [ $VERBOSE -eq 0 ]; then
		./$1  >>$LOG 2>&1
		err_code=$?
	else
		./$1 -v 2>&1 | tee -a $LOG
		err_code=$PIPESTATUS
	fi
	popd >/dev/null	

	if [ $err_code -eq 0 ]; then
		logfull `gettext "Test PASS"`
	else
		logfull `gettext "[!] Test FAIL with code: "`$err_code
		let ERRORS++
	fi
}

# Execute tests
for t in $TESTS; do
	logfull
	tbname=`basename $t`
	logfull "---[$tbname]: "`gettext "start test"`
	execute $t
	logfull "---[$tbname]: "`gettext "stop test"`
done

# Final report
echo

if [ $ERRORS -eq 0 ]; then
    echo `gettext "The testing was succesfully completed"`
else
    echo `gettext "[!] The testing was failed"`
    echo `gettext "Number of errors: "`$ERRORS
fi

rm -rf $TESTDIR_PATH
/usr/sbin/pdp-init-fs --after-test

exit 0
